@@ -4,13 +4,14 @@ from valhalla import Schema
 
 test_data = {
     'some_dict': {'one': 'fish', 'two': 'fish', 'red': 'fish', 'blue': 'fish'},
-    'some_list': ['alpha', 'bravo', 'charlie', 'delta']
+    'some_list': ['alpha', 'bravo', 'charlie', 'delta'],
+    'some_other_list': ['alpha', 'bravo', 'charlie']
 }
 
 
 def test_drop_keys():
     s = Schema()
-    s.some_dict.drop_keys(('one', 'two'))
+    s.some_dict.drop_keys('one', 'two')
 
     s.validate(test_data)
     assert_true(s.valid)
@@ -21,6 +22,7 @@ def test_drop_keys():
 def test_contains():
     s = Schema()
     s.some_list.contains('bravo')
+    s.some_other_list.contains('alpha', 'bravo')
 
     s.validate(test_data)
     assert_true(s.valid)
